@@ -1,4 +1,4 @@
-# $Id: FileTransfer.pm 7840 2013-05-30 12:24:31Z hurko $
+# $Id: FileTransfer.pm 8092 2013-07-16 14:28:57Z joostvb $
 # $URL: https://pong.uvt.nl/its-nettel/Netwerken/Procedures/libuvt-noc-perl/lib/UvT/NOC/FileTransfer.pm $
 
 use utf8;
@@ -7,6 +7,9 @@ use warnings FATAL => 'all';
 
 package UvT::NOC::FileTransfer;
 
+use parent qw( Exporter );
+our @EXPORT_OK = qw (downloadFileUsingFTP downloadFileUsingFTPS downloadFileUsingHTTPS downloadUserTrackingUsingHTTPS);
+
 use UvT::NOC::Util::FileUtil;
 use UvT::NOC::Config::Resource;
 use UvT::NOC::Net::FTPSSL;
@@ -179,6 +182,8 @@ sub downloadFileUsingHTTPS
 		$ENV{HTTPS_DEBUG} = $debug;
 
 		my $useragent = LWP::UserAgent->new();
+		# enforce SSLv3 voor brakke Oracle-SSL op uvtapp.uvt.nl
+		$useragent->ssl_opts( SSL_version => "SSLv3");
 		$useragent->credentials($host . ":" . $port, $realm, $username, $password);
 		my $request = HTTP::Request->new(GET => "$url");
 		my $response = $useragent->request($request);
